pub struct DateSeriesData<T>(/* private fields */);Expand description
Series data that is guaranteed to use a date-based index.
This is a newtype around SeriesData<T> that guarantees is_date_based() is true,
making date methods infallible.
Implementations
Sourceimpl<T> DateSeriesData<T>
impl<T> DateSeriesData<T>
Sourcepub fn try_new(inner: SeriesData<T>) -> Result<DateSeriesData<T>, SeriesData<T>>
pub fn try_new(inner: SeriesData<T>) -> Result<DateSeriesData<T>, SeriesData<T>>
Create a DateSeriesData from a SeriesData, returning Err if the index is not date-based.
Sourcepub fn into_inner(self) -> SeriesData<T>
pub fn into_inner(self) -> SeriesData<T>
Consume and return the inner SeriesData.
Sourcepub fn dates(&self) -> Option<impl Iterator<Item = Date>>
pub fn dates(&self) -> Option<impl Iterator<Item = Date>>
Returns an iterator over dates for the index range.
Returns None for sub-daily indexes (use timestamps() instead).
Sourcepub fn iter_dates(&self) -> Option<impl Iterator<Item = (Date, &T)>>
pub fn iter_dates(&self) -> Option<impl Iterator<Item = (Date, &T)>>
Iterate over (date, &value) pairs.
Returns None for sub-daily indexes (use iter_timestamps() instead).
Sourcepub fn timestamps(&self) -> impl Iterator<Item = Timestamp>
pub fn timestamps(&self) -> impl Iterator<Item = Timestamp>
Returns an iterator over timestamps for the index range (infallible). Works for all date-based indexes including sub-daily.
Sourcepub fn iter_timestamps(&self) -> impl Iterator<Item = (Timestamp, &T)>
pub fn iter_timestamps(&self) -> impl Iterator<Item = (Timestamp, &T)>
Iterate over (timestamp, &value) pairs (infallible). Works for all date-based indexes including sub-daily.
Methods from Deref<Target = SeriesData<T>>
Sourcepub fn is_date_based(&self) -> bool
pub fn is_date_based(&self) -> bool
Returns true if this series uses a date-based index.
Sourcepub fn dates(&self) -> Option<impl Iterator<Item = Date>>
pub fn dates(&self) -> Option<impl Iterator<Item = Date>>
Returns an iterator over dates for the index range.
Returns None for non-date-based and sub-daily indexes (use timestamps() instead).
Sourcepub fn timestamps(&self) -> Option<impl Iterator<Item = Timestamp>>
pub fn timestamps(&self) -> Option<impl Iterator<Item = Timestamp>>
Returns an iterator over timestamps for the index range.
Works for all date-based indexes including sub-daily.
Returns None for non-date-based indexes.