pub struct P2SHAddrIndex(/* private fields */);Trait Implementations
Sourceimpl Add<usize> for P2SHAddrIndex
impl Add<usize> for P2SHAddrIndex
Sourceimpl Bytes for P2SHAddrIndex
impl Bytes for P2SHAddrIndex
Sourcetype Array = <TypeIndex as Bytes>::Array
type Array = <TypeIndex as Bytes>::Array
The byte array type returned by
to_bytes.
For fixed-size types, this is [u8; N] where N is the size of the type.Sourcefn to_bytes(&self) -> <P2SHAddrIndex as Bytes>::Array
fn to_bytes(&self) -> <P2SHAddrIndex as Bytes>::Array
Serializes this value to bytes. Read more
Sourcefn from_bytes(bytes: &[u8]) -> Result<P2SHAddrIndex, Error>
fn from_bytes(bytes: &[u8]) -> Result<P2SHAddrIndex, Error>
Deserializes a value from bytes. Read more
Sourceconst IS_NATIVE_LAYOUT: bool = false
const IS_NATIVE_LAYOUT: bool = false
Whether the byte representation from
to_bytes is identical to the
in-memory representation of Self. When true, bulk operations can use
memcpy instead of per-element deserialization. Read moreSourceimpl CheckedSub for P2SHAddrIndex
impl CheckedSub for P2SHAddrIndex
fn checked_sub(self, rhs: P2SHAddrIndex) -> Option<P2SHAddrIndex>
Sourceimpl Clone for P2SHAddrIndex
impl Clone for P2SHAddrIndex
Sourcefn clone(&self) -> P2SHAddrIndex
fn clone(&self) -> P2SHAddrIndex
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for P2SHAddrIndex
impl Debug for P2SHAddrIndex
Sourceimpl Default for P2SHAddrIndex
impl Default for P2SHAddrIndex
Sourcefn default() -> P2SHAddrIndex
fn default() -> P2SHAddrIndex
Returns the “default value” for a type. Read more
Sourceimpl Deref for P2SHAddrIndex
impl Deref for P2SHAddrIndex
Sourceimpl DerefMut for P2SHAddrIndex
impl DerefMut for P2SHAddrIndex
Sourceimpl<'de> Deserialize<'de> for P2SHAddrIndex
impl<'de> Deserialize<'de> for P2SHAddrIndex
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<P2SHAddrIndex, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<P2SHAddrIndex, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for P2SHAddrIndex
impl Display for P2SHAddrIndex
Sourceimpl Formattable for P2SHAddrIndex
impl Formattable for P2SHAddrIndex
Sourceimpl From<P2SHAddrIndex> for StoredU16
impl From<P2SHAddrIndex> for StoredU16
Sourcefn from(value: P2SHAddrIndex) -> StoredU16
fn from(value: P2SHAddrIndex) -> StoredU16
Converts to this type from the input type.
Sourceimpl From<P2SHAddrIndex> for StoredU32
impl From<P2SHAddrIndex> for StoredU32
Sourcefn from(value: P2SHAddrIndex) -> StoredU32
fn from(value: P2SHAddrIndex) -> StoredU32
Converts to this type from the input type.
Sourceimpl From<P2SHAddrIndex> for StoredU64
impl From<P2SHAddrIndex> for StoredU64
Sourcefn from(value: P2SHAddrIndex) -> StoredU64
fn from(value: P2SHAddrIndex) -> StoredU64
Converts to this type from the input type.
Sourceimpl From<P2SHAddrIndex> for TypeIndex
impl From<P2SHAddrIndex> for TypeIndex
Sourcefn from(value: P2SHAddrIndex) -> TypeIndex
fn from(value: P2SHAddrIndex) -> TypeIndex
Converts to this type from the input type.
Sourceimpl From<P2SHAddrIndex> for u32
impl From<P2SHAddrIndex> for u32
Sourcefn from(value: P2SHAddrIndex) -> u32
fn from(value: P2SHAddrIndex) -> u32
Converts to this type from the input type.
Sourceimpl From<P2SHAddrIndex> for u64
impl From<P2SHAddrIndex> for u64
Sourcefn from(value: P2SHAddrIndex) -> u64
fn from(value: P2SHAddrIndex) -> u64
Converts to this type from the input type.
Sourceimpl From<P2SHAddrIndex> for usize
impl From<P2SHAddrIndex> for usize
Sourcefn from(value: P2SHAddrIndex) -> usize
fn from(value: P2SHAddrIndex) -> usize
Converts to this type from the input type.
Sourceimpl From<TypeIndex> for P2SHAddrIndex
impl From<TypeIndex> for P2SHAddrIndex
Sourcefn from(value: TypeIndex) -> P2SHAddrIndex
fn from(value: TypeIndex) -> P2SHAddrIndex
Converts to this type from the input type.
Sourceimpl From<u32> for P2SHAddrIndex
impl From<u32> for P2SHAddrIndex
Sourcefn from(value: u32) -> P2SHAddrIndex
fn from(value: u32) -> P2SHAddrIndex
Converts to this type from the input type.
Sourceimpl From<u64> for P2SHAddrIndex
impl From<u64> for P2SHAddrIndex
Sourcefn from(value: u64) -> P2SHAddrIndex
fn from(value: u64) -> P2SHAddrIndex
Converts to this type from the input type.
Sourceimpl From<usize> for P2SHAddrIndex
impl From<usize> for P2SHAddrIndex
Sourcefn from(value: usize) -> P2SHAddrIndex
fn from(value: usize) -> P2SHAddrIndex
Converts to this type from the input type.
Sourceimpl JsonSchema for P2SHAddrIndex
impl JsonSchema for P2SHAddrIndex
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for P2SHAddrIndex
impl Ord for P2SHAddrIndex
Sourcefn cmp(&self, other: &P2SHAddrIndex) -> Ordering
fn cmp(&self, other: &P2SHAddrIndex) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for P2SHAddrIndex
impl PartialEq for P2SHAddrIndex
Sourcefn eq(&self, other: &P2SHAddrIndex) -> bool
fn eq(&self, other: &P2SHAddrIndex) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for P2SHAddrIndex
impl PartialOrd for P2SHAddrIndex
Sourceimpl Pco for P2SHAddrIndex
impl Pco for P2SHAddrIndex
type NumberType = <TypeIndex as Pco>::NumberType
Sourceimpl PrintableIndex for P2SHAddrIndex
impl PrintableIndex for P2SHAddrIndex
Sourceimpl Serialize for P2SHAddrIndex
impl Serialize for P2SHAddrIndex
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for P2SHAddrIndex
impl Eq for P2SHAddrIndex
impl StructuralPartialEq for P2SHAddrIndex
impl TransparentPco<<TypeIndex as Pco>::NumberType> for P2SHAddrIndex