pub struct P2WPKHBytes(/* private fields */);Trait Implementations
Sourceimpl Bytes for P2WPKHBytes
impl Bytes for P2WPKHBytes
Sourcetype Array = <U8x20 as Bytes>::Array
type Array = <U8x20 as Bytes>::Array
The byte array type returned by
to_bytes.
For fixed-size types, this is [u8; N] where N is the size of the type.Sourcefn from_bytes(bytes: &[u8]) -> Result<P2WPKHBytes, Error>
fn from_bytes(bytes: &[u8]) -> Result<P2WPKHBytes, Error>
Deserializes a value from bytes. Read more
Sourceconst IS_NATIVE_LAYOUT: bool = false
const IS_NATIVE_LAYOUT: bool = false
Whether the byte representation from
to_bytes is identical to the
in-memory representation of Self. When true, bulk operations can use
memcpy instead of per-element deserialization. Read moreSourceimpl Clone for P2WPKHBytes
impl Clone for P2WPKHBytes
Sourcefn clone(&self) -> P2WPKHBytes
fn clone(&self) -> P2WPKHBytes
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for P2WPKHBytes
impl Debug for P2WPKHBytes
Sourceimpl Deref for P2WPKHBytes
impl Deref for P2WPKHBytes
Sourceimpl<'de> Deserialize<'de> for P2WPKHBytes
impl<'de> Deserialize<'de> for P2WPKHBytes
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<P2WPKHBytes, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<P2WPKHBytes, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for P2WPKHBytes
impl Display for P2WPKHBytes
Sourceimpl Formattable for P2WPKHBytes
impl Formattable for P2WPKHBytes
Sourcefn write_to(&self, buf: &mut Vec<u8>)
fn write_to(&self, buf: &mut Vec<u8>)
Write formatted UTF-8 bytes. Primary method — all others derive from it.
Sourcefn fmt_csv(&self, f: &mut String) -> Result<(), Error>
fn fmt_csv(&self, f: &mut String) -> Result<(), Error>
Write in CSV format. Override for types needing CSV escaping (e.g., quoting commas).
Sourceimpl From<&[u8]> for P2WPKHBytes
impl From<&[u8]> for P2WPKHBytes
Sourcefn from(value: &[u8]) -> P2WPKHBytes
fn from(value: &[u8]) -> P2WPKHBytes
Converts to this type from the input type.
Sourceimpl From<P2WPKHBytes> for AddrBytes
impl From<P2WPKHBytes> for AddrBytes
Sourcefn from(value: P2WPKHBytes) -> AddrBytes
fn from(value: P2WPKHBytes) -> AddrBytes
Converts to this type from the input type.
Sourceimpl From<U8x20> for P2WPKHBytes
impl From<U8x20> for P2WPKHBytes
Sourcefn from(value: U8x20) -> P2WPKHBytes
fn from(value: U8x20) -> P2WPKHBytes
Converts to this type from the input type.
Sourceimpl Hash for P2WPKHBytes
impl Hash for P2WPKHBytes
Sourceimpl JsonSchema for P2WPKHBytes
impl JsonSchema for P2WPKHBytes
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for P2WPKHBytes
impl Ord for P2WPKHBytes
Sourcefn cmp(&self, other: &P2WPKHBytes) -> Ordering
fn cmp(&self, other: &P2WPKHBytes) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for P2WPKHBytes
impl PartialEq for P2WPKHBytes
Sourcefn eq(&self, other: &P2WPKHBytes) -> bool
fn eq(&self, other: &P2WPKHBytes) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for P2WPKHBytes
impl PartialOrd for P2WPKHBytes
Sourceimpl Serialize for P2WPKHBytes
impl Serialize for P2WPKHBytes
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for P2WPKHBytes
impl StructuralPartialEq for P2WPKHBytes