pub struct ReplacementNode {
pub tx: RbfTx,
pub time: Timestamp,
pub full_rbf: bool,
pub interval: Option<u32>,
pub mined: Option<bool>,
pub replaces: Vec<ReplacementNode>,
}Expand description
One node in an RBF replacement tree. The node’s tx replaced each
entry in replaces, recursively.
Fields
tx: RbfTxtime: TimestampFirst-seen timestamp, duplicated here to match mempool.space’s on-the-wire shape.
full_rbf: boolAny predecessor in this subtree was non-signaling.
interval: Option<u32>Seconds between this node’s time and the successor that
replaced it. Omitted on the root of an RBF response.
mined: Option<bool>Some(true) iff this node’s tx is currently confirmed. Absent
on serialization otherwise.
replaces: Vec<ReplacementNode>Trait Implementations
Sourceimpl Clone for ReplacementNode
impl Clone for ReplacementNode
Sourcefn clone(&self) -> ReplacementNode
fn clone(&self) -> ReplacementNode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReplacementNode
impl Debug for ReplacementNode
Sourceimpl<'de> Deserialize<'de> for ReplacementNode
impl<'de> Deserialize<'de> for ReplacementNode
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ReplacementNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ReplacementNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReplacementNode
impl JsonSchema for ReplacementNode
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ReplacementNode
impl Serialize for ReplacementNode
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more